==> igloo_0_1_4.tar.tgz: igloo_0_1_4/igloo/language/1/barnraiser_01/node_structure.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');



//HEADER
$lang['hdr_node_rules'] = 						"node rules";
$lang['hdr_administration'] = 					"administration";
$lang['hdr_structure'] = 						"structure";
$lang['hdr_contact'] = 							"contact";
$lang['hdr_system'] = 							"system";
$lang['hdr_role'] = 							"role";
$lang['hdr_statistics'] = 						"statistics";


// ERROR
$lang['err_no_statistics'] = 					"Sorry, there are no statistics available.";


//BODY TEXT
$lang['txt_contact'] = 							"place your organisations contact details here.";
$lang['txt_administration'] = 					"place information about the administrators here. Include a description of contact procedures.";
$lang['txt_release_date'] = 					"released";
$lang['txt_install_date'] = 					"installed";
$lang['txt_version'] = 							"version";
$lang['txt_savannah'] = 						"Updates are available from <a href=\"http://savannah.gnu.org/\">Savannah</a>, the central point for development, distribution and maintenance of <a href=\"http://www.fsf.org/\">Free Software</a>.";
$lang['txt_role'] = 							"role type";
$lang['txt_membership_number'] = 				"membership";
$lang['txt_statistic_total_users'] = 			"total members";
$lang['txt_statistic_total_users_online'] = 	"total members online";

?>

==> igloo_0_1_9.tar.tgz: igloo_0_1_9/igloo/language/1/barnraiser_01/node_structure.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_node_rules'] = 						"group rules";
$lang['hdr_administration'] = 					"administration";
$lang['hdr_structure'] = 						"structure";
$lang['hdr_contact'] = 							"contact";
$lang['hdr_system'] = 							"system";
$lang['hdr_role'] = 							"role";
$lang['hdr_statistics'] = 						"statistics";


// ERROR
$lang['err_no_statistics'] = 					"Sorry, there are no statistics available.";


//BODY TEXT
$lang['txt_contact'] = 							"place your organisations contact details here.";
$lang['txt_administration'] = 					"place information about the administrators here. Include a description of contact procedures.";
$lang['txt_release_date'] = 					"released";
$lang['txt_install_date'] = 					"installed";
$lang['txt_version'] = 							"version";
$lang['txt_savannah'] = 						"Updates are available from <a href=\"http://savannah.gnu.org/\">Savannah</a>, the central point for development, distribution and maintenance of <a href=\"http://www.fsf.org/\">Free Software</a>.";
$lang['txt_role'] = 							"role type";
$lang['txt_membership_number'] = 				"membership";
$lang['txt_statistic_total_users'] = 			"total members";
$lang['txt_statistic_total_users_online'] = 	"total members online";

?>
